@@ -1,5 +1,5 @@
 
-# $Id: BySellerID.pm,v 2.7 2009/05/02 13:28:09 Martin Exp $
+# $Id: BySellerID.pm,v 2.12 2013-03-02 20:21:24 Martin Exp $
 
 =head1 NAME
 
@@ -42,8 +42,7 @@ Please tell the author if you find any!
 
 =head1 AUTHOR
 
-C<WWW::Search::Ebay::BySellerID> was written by and is maintained by
-Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =head1 LICENSE
 
@@ -58,11 +57,22 @@ use warnings;
 
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.7 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.12 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _native_setup_search
   {
   my ($self, $sQuery, $rh) = @_;
+  # As of 2013-03:
+  # http://www.ebay.com/sch/allhypedup82/m.html?_ipg=200&_sop=1&_rdc=1
+  $rh->{search_host} = 'http://www.ebay.com';
+  $rh->{search_path} = qq'/sch/$sQuery/m.html';
+  $self->{_options} = {
+                       _ipg => $self->{_hits_per_page},
+                       _rdc => 1,
+                       _sop => 1,
+                      };
+  return $self->SUPER::_native_setup_search($sQuery, $rh);
+  # Old version:
   $rh->{'MfcISAPICommand'} = 'MemberSearchResult';
   $rh->{'frompage'} = 'itemsbyseller';
   $rh->{'sofindtype'} = '26';
@@ -85,6 +95,13 @@ sub _native_setup_search
   return $self->SUPER::_native_setup_search('', $rh);
   } # _native_setup_search
 
+sub _columns
+  {
+  my $self = shift;
+  # This is for basic USA eBay:
+  return qw( junk bids price enddate );
+  } # _columns
+
 1;
 
 __END__
