@@ -1,5 +1,5 @@
 
-# $Id: Motors.pm,v 1.15 2009/05/31 14:57:28 Martin Exp $
+# $Id: Motors.pm,v 1.17 2013-03-02 19:51:36 Martin Exp $
 
 =head1 NAME
 
@@ -43,8 +43,7 @@ Please tell the author if you find any!
 
 =head1 AUTHOR
 
-C<WWW::Search::Ebay::Motors> was written by and is maintained by
-Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
 
 =head1 LEGALESE
 
@@ -67,26 +66,40 @@ use Carp;
 use Data::Dumper;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 1.15 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.17 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 sub _native_setup_search
   {
   my ($self, $native_query, $rhOptsArg) = @_;
   $rhOptsArg ||= {};
-  unless (ref($rhOptsArg) eq 'HASH')
+  if (ref($rhOptsArg) ne 'HASH')
     {
-    carp " --- second argument to _native_setup_search should be hashref, not arrayref";
-    return undef;
+    carp " --- second argument to _native_setup_search should be hashref";
+    return;
     } # unless
-  $rhOptsArg->{search_host} = 'http://motors.search.ebay.com';
+  # As of 2013-03:
+  # http://motors.shop.ebay.com/eBay-Motors-/6000/i.html?_nkw=bugatti&_trksid=p2050890.m570.l1313&_rdc=1
+  $rhOptsArg->{search_host} = 'http://motors.shop.ebay.com';
+  $rhOptsArg->{search_path} = '/eBay-Motors-/6000/i.html';
+  $self->{_options} = {
+                       _nkw => $native_query,
+                       _armrs => 1,
+                       # _trksid => 'p2050890.m570.l1313',
+                       # Turn off JavaScript:
+                       _jsoff => 1,
+                       # Search AUCTIONS ONLY:
+                       # LH_Auction => 1,
+                       _ipg => $self->{_hits_per_page},
+                       _rdc => 1,
+                      };
   return $self->SUPER::_native_setup_search($native_query, $rhOptsArg);
   } # _native_setup_search
 
 sub _columns
   {
   my $self = shift;
-  return qw( paypal bids price shipping enddate );
+  return qw( paypal bids price enddate );
   } # _columns
 
 1;
